==> astk-serveur-1.7.1.1.tbz: aster/ASTK/ASTK_SERV/lib/as_common_func.py <==
# -*- coding: iso-8859-1 -*-

# ==============================================================================
# COPYRIGHT (C) 1991 - 2003  EDF R&D                  WWW.CODE-ASTER.ORG
# THIS PROGRAM IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR MODIFY
# IT UNDER THE TERMS OF THE GNU GENERAL PUBLIC LICENSE AS PUBLISHED BY
# THE FREE SOFTWARE FOUNDATION; EITHER VERSION 2 OF THE LICENSE, OR
# (AT YOUR OPTION) ANY LATER VERSION.
#
# THIS PROGRAM IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL, BUT
# WITHOUT ANY WARRANTY; WITHOUT EVEN THE IMPLIED WARRANTY OF
# MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. SEE THE GNU
# GENERAL PUBLIC LICENSE FOR MORE DETAILS.
#
# YOU SHOULD HAVE RECEIVED A COPY OF THE GNU GENERAL PUBLIC LICENSE
# ALONG WITH THIS PROGRAM; IF NOT, WRITE TO EDF R&D CODE_ASTER,
#    1 AVENUE DU GENERAL DE GAULLE, 92141 CLAMART CEDEX, FRANCE.
# ==============================================================================

"""
   Some utilities for as_run.
"""

__revision__ = "$Id $"

# ----- differ messages translation
def _(mesg):
   return mesg

import os
from utils          import parse_config
from as_repart      import ResourceManager, PureLocalResource

#-------------------------------------------------------------------------------
def get_hostrc(run, prof):
   """Return hostrc object from profile or config.
   """
   mode = prof['mode'][0]
   hostrc = None
   if prof.Get('D', 'hostfile'):
      fhost = prof.Get('D', 'hostfile')[0]['path']
      if run.IsRemote(fhost) or True:
         tmphost = os.path.join(run['tmp_user'], 'hostfile.'+run['num_job'])
         run.ToDelete(tmphost)
         kret = run.Copy(tmphost, fhost)
         fhost = tmphost
      else:
         fhost = run.PathOnly(fhost)
   elif run.get('%s_distrib_hostfile' % mode):
      fhost = run['%s_distrib_hostfile' % mode]
   else:
      fhost = None
   if fhost:
      hostinfo = parse_config(fhost)
      run.DBG('hostinfo : %s' % hostinfo)
      hostrc = ResourceManager(hostinfo)
   else:
      hostrc = PureLocalResource(run)
   return hostrc

#-------------------------------------------------------------------------------
def get_timeout(run, prof, default=60.):
   """Return timeout value from profile or config or 60 seconds.
   """
   timeout = prof['timeout'][0]
   if timeout == '':
      timeout = run.get('timeout')
   try:
      timeout = float(eval(timeout))
   except Exception, msg:
      timeout = default
      run.DBG('ERROR : Invalid timeout : %s' % repr(timeout), 'Exception : %s' % msg)
   return timeout

==> astk-serveur-1.7.4.1.tbz: aster/ASTK/ASTK_SERV/lib/as_common_func.py <==
# -*- coding: iso-8859-1 -*-

# ==============================================================================
# COPYRIGHT (C) 1991 - 2003  EDF R&D                  WWW.CODE-ASTER.ORG
# THIS PROGRAM IS FREE SOFTWARE; YOU CAN REDISTRIBUTE IT AND/OR MODIFY
# IT UNDER THE TERMS OF THE GNU GENERAL PUBLIC LICENSE AS PUBLISHED BY
# THE FREE SOFTWARE FOUNDATION; EITHER VERSION 2 OF THE LICENSE, OR
# (AT YOUR OPTION) ANY LATER VERSION.
#
# THIS PROGRAM IS DISTRIBUTED IN THE HOPE THAT IT WILL BE USEFUL, BUT
# WITHOUT ANY WARRANTY; WITHOUT EVEN THE IMPLIED WARRANTY OF
# MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. SEE THE GNU
# GENERAL PUBLIC LICENSE FOR MORE DETAILS.
#
# YOU SHOULD HAVE RECEIVED A COPY OF THE GNU GENERAL PUBLIC LICENSE
# ALONG WITH THIS PROGRAM; IF NOT, WRITE TO EDF R&D CODE_ASTER,
#    1 AVENUE DU GENERAL DE GAULLE, 92141 CLAMART CEDEX, FRANCE.
# ==============================================================================

"""
   Some utilities for as_run.
"""

__revision__ = "$Id $"

# ----- differ messages translation
def _(mesg):
   return mesg

import os
from utils          import parse_config
from as_repart      import ResourceManager, PureLocalResource

#-------------------------------------------------------------------------------
def get_hostrc(run, prof):
   """Return hostrc object from profile or config.
   """
   mode = prof['mode'][0]
   hostrc = None
   if prof.Get('D', 'hostfile'):
      fhost = prof.Get('D', 'hostfile')[0]['path']
      if run.IsRemote(fhost) or True:
         tmphost = os.path.join(run['tmp_user'], 'hostfile.'+run['num_job'])
         run.ToDelete(tmphost)
         kret = run.Copy(tmphost, fhost)
         fhost = tmphost
      else:
         fhost = run.PathOnly(fhost)
   elif run.get('%s_distrib_hostfile' % mode):
      fhost = run['%s_distrib_hostfile' % mode]
   else:
      fhost = None
   if fhost:
      hostinfo = parse_config(fhost)
      run.DBG('hostinfo : %s' % hostinfo)
      hostrc = ResourceManager(hostinfo)
   else:
      hostrc = PureLocalResource(run)
   return hostrc

#-------------------------------------------------------------------------------
def get_timeout(run, prof, default=60.):
   """Return timeout value from profile or config or 60 seconds.
   """
   timeout = prof['timeout'][0]
   if timeout == '':
      timeout = default
   try:
      timeout = float(eval(str(timeout)))
   except Exception, msg:
      run.DBG('ERROR : Invalid timeout : %s' % repr(timeout), 'Exception : %s' % msg)
      timeout = default
   return timeout
